pub struct Renderer { /* private fields */ }Implementations
Sourceimpl Renderer
impl Renderer
pub fn new(engine: Engine, settings: Settings) -> Self
Sourcepub fn draw(
&mut self,
clear_color: Option<Color>,
target: &TextureView,
viewport: &Viewport,
) -> CommandEncoder
pub fn draw( &mut self, clear_color: Option<Color>, target: &TextureView, viewport: &Viewport, ) -> CommandEncoder
Record commands that draw the current primitives to the target texture view.
You must call finish and recall when submitting
the resulting wgpu::CommandEncoder.
pub fn present( &mut self, clear_color: Option<Color>, _format: TextureFormat, frame: &TextureView, viewport: &Viewport, ) -> SubmissionIndex
Sourcepub fn screenshot(
&mut self,
viewport: &Viewport,
background_color: Color,
) -> Vec<u8> ⓘ
pub fn screenshot( &mut self, viewport: &Viewport, background_color: Color, ) -> Vec<u8> ⓘ
Renders the current surface to an offscreen buffer.
Returns RGBA bytes of the texture data.
Sourcepub fn finish(&mut self)
pub fn finish(&mut self)
Prepares currently mapped buffers for use in a submission.
Usually, this method is only needed if you are calling Renderer::draw directly,
instead of relying on Renderer::present.
You must call this method before submitting the resulting wgpu::CommandEncoder
of Renderer::draw to a wgpu::Queue.
Sourcepub fn recall(&mut self)
pub fn recall(&mut self)
Recalls all of the closed buffers back to be reused.
Usually, this method is only needed if you are calling Renderer::draw directly,
instead of relying on Renderer::present to a wgpu::Queue.
You must call this method after submitting the resulting wgpu::CommandEncoder
of Renderer::draw to a wgpu::Queue.