[−][src]Module iced_wgpu::widget
Use the widgets supported out-of-the-box.
Re-exports
For convenience, the contents of this module are available at the root module. Therefore, you can directly type:
use iced_wgpu::{button, Button};
Re-exports
pub use button::Button; |
pub use checkbox::Checkbox; |
pub use container::Container; |
pub use pane_grid::PaneGrid; |
pub use progress_bar::ProgressBar; |
pub use radio::Radio; |
pub use scrollable::Scrollable; |
pub use slider::Slider; |
pub use text_input::TextInput; |
Modules
| button | Allow your users to perform actions by pressing a button. |
| checkbox | Show toggle controls using checkboxes. |
| container | Decorate content and apply alignment. |
| pane_grid | Let your users split regions of your application and organize layout dynamically. |
| progress_bar | Allow your users to perform actions by pressing a button. |
| radio | Create choices using radio buttons. |
| scrollable | Navigate an endless amount of content with a scrollbar. |
| slider | Display an interactive selector of a single value from a range of values. |
| text_input | Display fields that can be filled with text. |