Compositor

Struct Compositor 

pub struct Compositor { /* private fields */ }
A window graphics backend for iced powered by wgpu.

Implementations

Source

impl Compositor

pub async fn request<W: Window>( settings: Settings, compatible_window: Option<W>, shell: Shell, ) -> Result<Self, Error>

Requests a new Compositor with the given Settings.

Returns None if no compatible graphics adapter could be found.